@@ -1,5 +1,5 @@
 # Used to avoid incorrect notes of "no visible binding"
-utils::globalVariables(c("feature","count","cond"))
+utils::globalVariables(c("feature","count","cond","count_minus","count_plus"))
 
 #' Politeness plot
 #'
@@ -147,24 +147,6 @@ politenessPlot<-function(df_polite,
   }
   split.data<-split.data[(split.data$feature%in%nonblanks)&(split.data$feature%in%split.enough),]
   ######################################################
-  if(binary){
-    map.type<-"Percentage of Documents Using Feature"
-    split.data$se <- sqrt(((split.data$count)*(1-split.data$count))/nrow(df_polite))
-    y.breaks <- seq(0,1,.25)
-    y.labels <- paste0(seq(0,100,25),"%")
-    y.trans <- "identity"
-  } else if(averages){
-    map.type<-"Feature Count per 100 Words"
-    tick.set<-c(0.1,0.5,1,2,5,10,25)
-    y.labels <- y.breaks <- tick.set
-    y.trans <- "sqrt"
-  } else {
-    map.type<-"Feature Count per Document"
-    tick.set<-c(0.1,0.5,1,2,5,10,20,50,100,200,500,1000)
-    y.labels <- y.breaks <- tick.set
-    y.trans <- "sqrt"
-  }
-  ######################################################
   # Custom feature ordering
   ######################################################
   if((!is.null(features))&ordered){
@@ -186,7 +168,33 @@ politenessPlot<-function(df_polite,
                                ordered=TRUE,
                                levels=f.order)
   }
-
+  ######################################################
+  if(binary){
+    map.type<-"Percentage of Documents Using Feature"
+    split.data$se <- sqrt(((split.data$count)*(1-split.data$count))/nrow(df_polite))
+    y.breaks <- seq(0,1,.25)
+    y.labels <- paste0(seq(0,100,25),"%")
+    y.trans <- "identity"
+  } else if(averages){
+    map.type<-"Feature Count per 100 Words"
+    if(max(split.data$count)>20){
+      tick.set<-c(1,5,10,25, 50)
+    } else{
+      tick.set<-c(0.1,0.5,1,2,5,10,25)
+    }
+    y.labels <- y.breaks <- tick.set
+    y.trans <- "sqrt"
+  } else {
+    map.type<-"Feature Count per Document"
+    if(max(split.data$count)>20){
+      tick.set<-c(1,5,10,20,50,100,200,500,1000)
+    }
+    else{
+      tick.set<-c(0.1,0.5,1,2,5,10,20,50)
+    }
+    y.labels <- y.breaks <- tick.set
+    y.trans <- "sqrt"
+  }
   ######################################################
 
   split.data$cond<-factor(split.data$cond,ordered=TRUE,levels=rev(split_levels))
@@ -200,7 +208,7 @@ politenessPlot<-function(df_polite,
                   width=2) +
     ggplot2::geom_bar(position=ggplot2::position_dodge(width = 0.8),
                       stat="identity") +
-    ggplot2::geom_errorbar(ggplot2::aes_string(ymin="count_minus", ymax="count_plus"), width=0.3,
+    ggplot2::geom_errorbar(ggplot2::aes(ymin=count_minus, ymax=count_plus), width=0.3,
                            position=ggplot2::position_dodge(width = 0.8)) +
     ggplot2::coord_flip() +
     ggplot2::scale_x_discrete(name="", breaks=colnames(df_polite),
